ColorTones class

Inheritance

Constructors

ColorTones(int primary, Map<int, Color> swatch)
const

Properties

a double
The alpha channel of this color.
finalinherited
alpha int
The alpha channel of this color in an 8 bit value.
no setterinherited
b double
The blue channel of this color.
finalinherited
blue int
The blue channel of this color in an 8 bit value.
no setterinherited
colorSpace ColorSpace
The color space of this color.
finalinherited
g double
The green channel of this color.
finalinherited
green int
The green channel of this color in an 8 bit value.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
keys Iterable<int>
Returns the valid keys for accessing operator[].
no setterinherited
opacity double
The alpha channel of this color as a double.
no setterinherited
r double
The red channel of this color.
finalinherited
red int
The red channel of this color in an 8 bit value.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shade100 Color
no setter
shade1000 Color
no setter
shade1100 Color
no setter
shade1200 Color
no setter
shade1300 Color
no setter
shade1400 Color
no setter
shade200 Color
no setter
shade300 Color
no setter
shade400 Color
no setter
shade50 Color
no setter
shade500 Color
no setter
shade600 Color
no setter
shade700 Color
no setter
shade75 Color
no setter
shade800 Color
no setter
shade900 Color
no setter
value int
A 32 bit value representing this color.
no setterinherited

Methods

computeLuminance() double
Returns a brightness value between 0 for darkest and 1 for lightest.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toARGB32() int
Returns a 32-bit value representing this color.
inherited
toString() String
A string representation of this object.
inherited
withAlpha(int a) Color
Returns a new color that matches this color with the alpha channel replaced with a (which ranges from 0 to 255).
inherited
withBlue(int b) Color
Returns a new color that matches this color with the blue channel replaced with b (which ranges from 0 to 255).
inherited
withGreen(int g) Color
Returns a new color that matches this color with the green channel replaced with g (which ranges from 0 to 255).
inherited
withOpacity(double opacity) Color
Returns a new color that matches this color with the alpha channel replaced with the given opacity (which ranges from 0.0 to 1.0).
inherited
withRed(int r) Color
Returns a new color that matches this color with the red channel replaced with r (which ranges from 0 to 255).
inherited
withValues({double? alpha, double? red, double? green, double? blue, ColorSpace? colorSpace}) Color
Returns a new color with the provided components updated.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int key) Color?
Returns an element of the swatch table.
inherited